@@ -1,11 +1,10 @@
 """ Contains all the data models used in inputs/outputs """
 
 from .auth_session import AuthSession
+from .environment import Environment
 from .error_message import ErrorMessage
 from .file_conversion import FileConversion
 from .file_conversion_status import FileConversionStatus
 from .instance_metadata import InstanceMetadata
-from .instance_metadata_environment import InstanceMetadataEnvironment
-from .ping_response_200 import PingResponse200
-from .ping_response_200_message import PingResponse200Message
-from .valid_file_types import ValidFileTypes
+from .message import Message
+from .valid_file_type import ValidFileType
